==> 1.0.1.tar.gz: lib/service/push_api.dart <==
import 'dart:io';
import 'dart:convert';
import 'package:push_sdk/model/api_resp.dart';
import 'package:push_sdk/service/api_send_service.dart';
import '../global.dart';
import 'local_data_helper.dart';

class pushApi {
  // Singleton 單例模式，確保一個類別只有一個實例
  pushApi._privateConstructor();
  static final pushApi instance = pushApi._privateConstructor();
  final dataHelper = DataHelper.instance;

  /// 設備初始化時，取得 device_uuid & device_id
  PushDeviceGetUUID() {
    GWSend("PushDeviceGetUUID").then((response) {
      var body = response.body;
      getUUIDResp data = getUUIDResp.fromJson(jsonDecode(body.toString()));
      dataHelper.setData("device_id", data.device_id);
      dataHelper.setData("device_uuid", data.device_uuid);
      dataHelper.getStorageData();
      PushDeviceInfoUpdate();
    });
  }

  /// 設備基本資料新增註冊或更新相關資訊
  PushDeviceInfoUpdate({String domain_key = "",String token = ""}) {
    /**
     * 註冊過，判斷 token, domain_key, stamp決定要不要更新
        1. token與記錄的不同
        2. domain_key與記錄的不同
        3. stamp跨日
     * */
    if(Globals.token != token ||
        Globals.domain_key != domain_key ||
        DateTime.fromMillisecondsSinceEpoch(int.parse(Globals.stamp ?? "")).difference(DateTime.now()).inDays != 0) {
        var postdata = {
          "domain_key": domain_key,
          "device_type": Platform.isIOS ? "I" : "G",
          "os_version_str": Globals.osVersion,
          "app_version_str": Globals.appVersion,
          "token": token
        };

        GWSend("PushDeviceInfoUpdate", postdata: postdata).then((response) {
          var body = response.body;
          infoUpdateResp data = infoUpdateResp.fromJson(jsonDecode(body.toString()));
          dataHelper.setData("device_id", data.device_id);
          dataHelper.setData("device_uuid", data.device_uuid);
          dataHelper.setData("domain_key", domain_key);
          dataHelper.setData("token", token);
          dataHelper.setData("stamp", data.sequence);
          dataHelper.getStorageData();
        });
    }
  }

  /// 裝置端查詢訊息內容查詢更新已讀
  Future<contentQueryResp> PushDeviceContentQuery(int message_id,{String domain_key = ""}) {
    var postdata = {
      "domain_key": domain_key,
      "message_id": message_id
    };

    return GWSend("PushDeviceContentQuery", postdata: postdata).then((response) {
      return contentQueryResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 裝置端刪除多筆或是單筆訊息
  Future<commonResp> PushDeviceMessageDel(String message_id,{String domain_key = ""}) {
    var postdata = {
      "domain_key": domain_key,
      "message_id": message_id
    };

    return GWSend("PushDeviceMessageDel", postdata: postdata).then((response) {
      return commonResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 裝置端查詢訊息列表
  Future<messageQueryResp> PushDeviceMessageQuery({String domain_key = "", int counts = 200, String category = "", int ?start_point}) {
    var postdata = {
      "domain_key": domain_key,
      "counts": counts,
      "category": category,
      "start_point": start_point,
    };

    return GWSend("PushDeviceMessageQuery", postdata: postdata).then((response) {
      return messageQueryResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 裝置端多筆已讀
  Future<commonResp> PushDeviceMessageRead(String message_id,{String domain_key = ""}) {
    var postdata = {
      "domain_key": domain_key,
      "message_id": message_id
    };

    return GWSend("PushDeviceMessageRead", postdata: postdata).then((response) {
      return commonResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 設備推播開關查詢
  Future<statusQueryResp> PushDeviceStatusQuery({String is_private = "ALL"}) {
    var postdata = {
      "is_private": is_private
    };

    return GWSend("PushDeviceStatusQuery", postdata: postdata).then((response) {
      return statusQueryResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 設備開關更新功能使用JSON批次更新
  Future<commonResp> PushDeviceStatusUpdate(Map<String,dynamic> postdata) {
    return GWSend("PushDeviceStatusUpdate", postdata: postdata).then((response) {
      return commonResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 設備訊息未讀筆數查詢
  Future<unReadCountResp> PushDeviceUnReadCount({String is_private = "ALL",String domain_key = ""}) {
    var postdata = {
      "is_private": is_private,
      "domain_key": domain_key
    };

    return GWSend("PushDeviceStatusQuery", postdata: postdata).then((response) {
      return unReadCountResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 裝置設備帳號手動綁定一對一(如果自動綁定可以不使用本API)
  Future<commonResp> PushDeviceBindingAdd(String domain_key) {
    var postdata = {
      "domain_key": domain_key
    };

    return GWSend("PushDeviceBindingAdd", postdata: postdata).then((response) {
      return commonResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 設備登入帳號綁定查詢
  Future<bindingQueryResp> PushDeviceBindingQuery(String domain_key) {
    var postdata = {
      "domain_key": domain_key
    };

    return GWSend("PushDeviceBindingQuery", postdata: postdata).then((response) {
      return bindingQueryResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 設備帳號綁定解除
  Future<commonResp> PushDeviceBindingRemove(int serial_no) {
    var postdata = {
      "serial_no": serial_no
    };
    return GWSend("PushDeviceBindingRemove", postdata: postdata).then((response) {
      return commonResp.fromJson(jsonDecode(response.body.toString()));
    });
  }
}

==> 1.0.3.tar.gz: lib/service/push_api.dart <==
import 'dart:io';
import 'dart:convert';
import 'package:push_sdk/model/api_resp.dart';
import 'package:push_sdk/service/api_send_service.dart';
import '../global.dart';
import 'local_data_helper.dart';

class pushApi {
  // Singleton 單例模式，確保一個類別只有一個實例
  pushApi._privateConstructor();
  static final pushApi instance = pushApi._privateConstructor();
  final dataHelper = DataHelper.instance;

  /// 設備初始化時，取得 device_uuid & device_id
  PushDeviceGetUUID() {
    GWSend("PushDeviceGetUUID").then((response) async {
      var body = response.body;
      getUUIDResp data = getUUIDResp.fromJson(jsonDecode(body.toString()));
      dataHelper.setData("device_id", data.device_id.toString());
      dataHelper.setData("device_uuid", data.device_uuid);
      dataHelper.setData("stamp", "${data.sequence}000");
      await dataHelper.getStorageData();
      PushDeviceInfoUpdate();
    });
  }

  /// 設備基本資料新增註冊或更新相關資訊
  PushDeviceInfoUpdate({String domain_key = "",String token = ""}) {
    /**
     * 註冊過，判斷 token, domain_key, stamp決定要不要更新
        1. token與記錄的不同
        2. domain_key與記錄的不同
        3. stamp跨日
     * */
    if(Globals.token != token ||
        Globals.domain_key != domain_key ||
        DateTime.fromMillisecondsSinceEpoch(int.parse(Globals.stamp ?? '0'),isUtc: true).difference(DateTime.now()).inDays != 0) {
        var postdata = {
          "domain_key": domain_key,
          "device_type": Platform.isIOS ? "I" : "G",
          "os_version_str": Globals.osVersion,
          "app_version_str": Globals.appVersion,
          "token": token
        };

        GWSend("PushDeviceInfoUpdate", postdata: postdata).then((response) {
          var body = response.body;
          infoUpdateResp data = infoUpdateResp.fromJson(jsonDecode(body.toString()));
          dataHelper.setData("device_id", data.device_id.toString());
          dataHelper.setData("device_uuid", data.device_uuid);
          dataHelper.setData("domain_key", domain_key);
          dataHelper.setData("token", token);
          dataHelper.setData("stamp", "${data.sequence}000");
          dataHelper.getStorageData();
        });
    }
  }

  /// 裝置端查詢訊息內容查詢更新已讀
  Future<contentQueryResp> PushDeviceContentQuery(int message_id,{String domain_key = ""}) {
    var postdata = {
      "domain_key": domain_key,
      "message_id": message_id
    };

    return GWSend("PushDeviceContentQuery", postdata: postdata).then((response) {
      return contentQueryResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 裝置端刪除多筆或是單筆訊息
  Future<commonResp> PushDeviceMessageDel(String message_id,{String domain_key = ""}) {
    var postdata = {
      "domain_key": domain_key,
      "message_id": message_id
    };

    return GWSend("PushDeviceMessageDel", postdata: postdata).then((response) {
      return commonResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 裝置端查詢訊息列表
  Future<messageQueryResp> PushDeviceMessageQuery({String domain_key = "", int counts = 200, String category = "", int ?start_point}) {
    var postdata = {
      "domain_key": domain_key,
      "counts": counts,
      "category": category,
      "start_point": start_point,
    };

    return GWSend("PushDeviceMessageQuery", postdata: postdata).then((response) {
      return messageQueryResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 裝置端多筆已讀
  Future<commonResp> PushDeviceMessageRead(String message_id,{String domain_key = ""}) {
    var postdata = {
      "domain_key": domain_key,
      "message_id": message_id
    };

    return GWSend("PushDeviceMessageRead", postdata: postdata).then((response) {
      return commonResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 設備推播開關查詢
  Future<statusQueryResp> PushDeviceStatusQuery({String is_private = "ALL"}) {
    var postdata = {
      "is_private": is_private
    };

    return GWSend("PushDeviceStatusQuery", postdata: postdata).then((response) {
      return statusQueryResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 設備開關更新功能使用JSON批次更新
  Future<commonResp> PushDeviceStatusUpdate(Map<String,dynamic> postdata) {
    return GWSend("PushDeviceStatusUpdate", postdata: postdata).then((response) {
      return commonResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 設備訊息未讀筆數查詢
  Future<unReadCountResp> PushDeviceUnReadCount({String is_private = "ALL",String domain_key = ""}) {
    var postdata = {
      "is_private": is_private,
      "domain_key": domain_key
    };

    return GWSend("PushDeviceStatusQuery", postdata: postdata).then((response) {
      return unReadCountResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 裝置設備帳號手動綁定一對一(如果自動綁定可以不使用本API)
  Future<commonResp> PushDeviceBindingAdd(String domain_key) {
    var postdata = {
      "domain_key": domain_key
    };

    return GWSend("PushDeviceBindingAdd", postdata: postdata).then((response) {
      return commonResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 設備登入帳號綁定查詢
  Future<bindingQueryResp> PushDeviceBindingQuery(String domain_key) {
    var postdata = {
      "domain_key": domain_key
    };

    return GWSend("PushDeviceBindingQuery", postdata: postdata).then((response) {
      return bindingQueryResp.fromJson(jsonDecode(response.body.toString()));
    });
  }

  /// 設備帳號綁定解除
  Future<commonResp> PushDeviceBindingRemove(int serial_no) {
    var postdata = {
      "serial_no": serial_no
    };
    return GWSend("PushDeviceBindingRemove", postdata: postdata).then((response) {
      return commonResp.fromJson(jsonDecode(response.body.toString()));
    });
  }
}
